@@ -59,7 +59,7 @@ demoteHeaders = withTags $ \tag -> case tag of
 
 --------------------------------------------------------------------------------
 isUrlAttribute :: String -> Bool
-isUrlAttribute = (`elem` ["src", "href", "data", "poster"])
+isUrlAttribute = (`elem` ["src", "href", "data", "poster", "srcset"])
 
 
 --------------------------------------------------------------------------------
